# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/mxns/03_data.ipynb.

# %% auto 0
__all__ = ['DataMixin']

# %% ../../nbs/mxns/03_data.ipynb 6
import os, pathlib
from abc import abstractmethod

# %% ../../nbs/mxns/03_data.ipynb 8
from typing import Callable, Optional

# %% ../../nbs/mxns/03_data.ipynb 10
#| export


# %% ../../nbs/mxns/03_data.ipynb 12
#| export


# %% ../../nbs/mxns/03_data.ipynb 14
class DataMixin:
    @abstractmethod
    def load(self): ...
