# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/plib/00__init__.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/plib/00__init__.ipynb 3
from itertools import chain
from . import lib as pathlib, psx as posixpath, wdx as ntpath
from .lib import *
from .psx import *
from .wdx import *

# %% ../../nbs/plib/00__init__.ipynb 4
__all__ = sorted(set(chain(*[
    mod.__all__ for mod in (pathlib, posixpath, ntpath, )
])))
