# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/04_data.ipynb.

# %% auto 0
__all__ = ['DataXath', 'DataPath', 'DataFile', 'DataDir']

# %% ../nbs/04_data.ipynb 6
#| export


# %% ../nbs/04_data.ipynb 8
#| export


# %% ../nbs/04_data.ipynb 10
#| export


# %% ../nbs/04_data.ipynb 12
#| export


# %% ../nbs/04_data.ipynb 14
from .expt import ExpectedXath, ExpectedPath, ExpectedDir, ExpectedFile
from .mxns.data import DataMixin
from .mxns.kind import FileKindMixin, DirKindMixin

# %% ../nbs/04_data.ipynb 16
class DataXath(ExpectedXath, DataMixin):
    ...

# %% ../nbs/04_data.ipynb 18
class DataPath(DataXath):
    ...

# %% ../nbs/04_data.ipynb 20
# NOTE: could alternatively be defined as `class DataFile(ExpectedFile, DataPath):`
class DataFile(FileKindMixin, DataPath):
    file: ExpectedFile()    

# %% ../nbs/04_data.ipynb 22
class DataDir(DirKindMixin, DataPath):
    dir: ExpectedDir()
