# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_expt.ipynb.

# %% auto 0
__all__ = ['ExpectedXath', 'ExpectedPath', 'ExpectedFile', 'ExpectedDir']

# %% ../nbs/03_expt.ipynb 6
#| export


# %% ../nbs/03_expt.ipynb 8
#| export


# %% ../nbs/03_expt.ipynb 10
#| export


# %% ../nbs/03_expt.ipynb 12
#| export


# %% ../nbs/03_expt.ipynb 14
from .leaf import LeafXath, LeafPath, LeafFile, LeafDir
from .mxns.expt import ExpectedMixin
from .mxns.kind import FileKindMixin, DirKindMixin

# %% ../nbs/03_expt.ipynb 16
class ExpectedXath(LeafXath, ExpectedMixin):
    ...

# %% ../nbs/03_expt.ipynb 18
class ExpectedPath(ExpectedXath):
    ...

# %% ../nbs/03_expt.ipynb 20
class ExpectedFile(FileKindMixin, ExpectedPath):
    file: LeafFile()
    ...

# %% ../nbs/03_expt.ipynb 22
# NOTE: could alternatively be defined as `ExpectedDir(LeafDir, ExpectedMixin)`
class ExpectedDir(DirKindMixin, ExpectedPath):
    dir: LeafDir()
