# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/xath',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/xath',
                'lib_path': 'xath'},
  'syms': { 'xath.base': { 'xath.base.Dir': ('base.html#dir', 'xath/base.py'),
                           'xath.base.File': ('base.html#file', 'xath/base.py'),
                           'xath.base.Path': ('base.html#path', 'xath/base.py'),
                           'xath.base.Xath': ('base.html#xath', 'xath/base.py'),
                           'xath.base.Xath.__init__': ('base.html#xath.__init__', 'xath/base.py'),
                           'xath.base.Xath.__new__': ('base.html#xath.__new__', 'xath/base.py'),
                           'xath.base.Xath.full': ('base.html#xath.full', 'xath/base.py'),
                           'xath.base.Xath.kind': ('base.html#xath.kind', 'xath/base.py'),
                           'xath.base.Xath.makecopy': ('base.html#xath.makecopy', 'xath/base.py'),
                           'xath.base.Xath.name': ('base.html#xath.name', 'xath/base.py'),
                           'xath.base.Xath.pathname': ('base.html#xath.pathname', 'xath/base.py'),
                           'xath.base.Xath.tree': ('base.html#xath.tree', 'xath/base.py'),
                           'xath.base.Xath.update': ('base.html#xath.update', 'xath/base.py'),
                           'xath.base.Xath.view': ('base.html#xath.view', 'xath/base.py')},
            'xath.data': { 'xath.data.DataDir': ('data.html#datadir', 'xath/data.py'),
                           'xath.data.DataFile': ('data.html#datafile', 'xath/data.py'),
                           'xath.data.DataPath': ('data.html#datapath', 'xath/data.py'),
                           'xath.data.DataXath': ('data.html#dataxath', 'xath/data.py')},
            'xath.expt': { 'xath.expt.ExpectedDir': ('expt.html#expecteddir', 'xath/expt.py'),
                           'xath.expt.ExpectedFile': ('expt.html#expectedfile', 'xath/expt.py'),
                           'xath.expt.ExpectedPath': ('expt.html#expectedpath', 'xath/expt.py'),
                           'xath.expt.ExpectedXath': ('expt.html#expectedxath', 'xath/expt.py')},
            'xath.leaf': { 'xath.leaf.LeafDir': ('leaf.html#leafdir', 'xath/leaf.py'),
                           'xath.leaf.LeafFile': ('leaf.html#leaffile', 'xath/leaf.py'),
                           'xath.leaf.LeafPath': ('leaf.html#leafpath', 'xath/leaf.py'),
                           'xath.leaf.LeafXath': ('leaf.html#leafxath', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.__init__': ('leaf.html#leafxath.__init__', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.__rtruediv__': ('leaf.html#leafxath.__rtruediv__', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.__truediv__': ('leaf.html#leafxath.__truediv__', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.base': ('leaf.html#leafxath.base', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.canbechild': ('leaf.html#leafxath.canbechild', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.canbeparent': ('leaf.html#leafxath.canbeparent', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.leaf': ('leaf.html#leafxath.leaf', 'xath/leaf.py'),
                           'xath.leaf.LeafXath.path': ('leaf.html#leafxath.path', 'xath/leaf.py')},
            'xath.mxns.data': { 'xath.mxns.data.DataMixin': ('mxns/data.html#datamixin', 'xath/mxns/data.py'),
                                'xath.mxns.data.DataMixin.load': ('mxns/data.html#datamixin.load', 'xath/mxns/data.py')},
            'xath.mxns.expt': { 'xath.mxns.expt.ExpectedMixin': ('mxns/expt.html#expectedmixin', 'xath/mxns/expt.py'),
                                'xath.mxns.expt.ExpectedMixin.__init__': ('mxns/expt.html#expectedmixin.__init__', 'xath/mxns/expt.py'),
                                'xath.mxns.expt.ExpectedMixin.isvalid': ('mxns/expt.html#expectedmixin.isvalid', 'xath/mxns/expt.py'),
                                'xath.mxns.expt.ExpectedMixin.makeprops': ('mxns/expt.html#expectedmixin.makeprops', 'xath/mxns/expt.py')},
            'xath.mxns.kind': { 'xath.mxns.kind.DirKindMixin': ('mxns/kind.html#dirkindmixin', 'xath/mxns/kind.py'),
                                'xath.mxns.kind.DirKindMixin.dirname': ('mxns/kind.html#dirkindmixin.dirname', 'xath/mxns/kind.py'),
                                'xath.mxns.kind.FileKindMixin': ('mxns/kind.html#filekindmixin', 'xath/mxns/kind.py'),
                                'xath.mxns.kind.FileKindMixin.filename': ('mxns/kind.html#filekindmixin.filename', 'xath/mxns/kind.py')},
            'xath.mxns.plib': { 'xath.mxns.plib.PathLibMixin': ('mxns/plib.html#pathlibmixin', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__bytes__': ('mxns/plib.html#pathlibmixin.__bytes__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__eq__': ('mxns/plib.html#pathlibmixin.__eq__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__fspath__': ('mxns/plib.html#pathlibmixin.__fspath__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__ge__': ('mxns/plib.html#pathlibmixin.__ge__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__gt__': ('mxns/plib.html#pathlibmixin.__gt__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__hash__': ('mxns/plib.html#pathlibmixin.__hash__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__init__': ('mxns/plib.html#pathlibmixin.__init__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__le__': ('mxns/plib.html#pathlibmixin.__le__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__lt__': ('mxns/plib.html#pathlibmixin.__lt__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__new__': ('mxns/plib.html#pathlibmixin.__new__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__reduce__': ('mxns/plib.html#pathlibmixin.__reduce__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__repr__': ('mxns/plib.html#pathlibmixin.__repr__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__rtruediv__': ( 'mxns/plib.html#pathlibmixin.__rtruediv__',
                                                                              'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__str__': ('mxns/plib.html#pathlibmixin.__str__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.__truediv__': ('mxns/plib.html#pathlibmixin.__truediv__', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._flavour': ('mxns/plib.html#pathlibmixin._flavour', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._format_parsed_parts': ( 'mxns/plib.html#pathlibmixin._format_parsed_parts',
                                                                                      'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._from_parsed_parts': ( 'mxns/plib.html#pathlibmixin._from_parsed_parts',
                                                                                    'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._make_child_relpath': ( 'mxns/plib.html#pathlibmixin._make_child_relpath',
                                                                                     'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._parse_args': ('mxns/plib.html#pathlibmixin._parse_args', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin._scandir': ('mxns/plib.html#pathlibmixin._scandir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.absolute': ('mxns/plib.html#pathlibmixin.absolute', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.anchor': ('mxns/plib.html#pathlibmixin.anchor', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.as_posix': ('mxns/plib.html#pathlibmixin.as_posix', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.as_uri': ('mxns/plib.html#pathlibmixin.as_uri', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.chmod': ('mxns/plib.html#pathlibmixin.chmod', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.clsname': ('mxns/plib.html#pathlibmixin.clsname', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.cwd': ('mxns/plib.html#pathlibmixin.cwd', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.delete': ('mxns/plib.html#pathlibmixin.delete', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.drive': ('mxns/plib.html#pathlibmixin.drive', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.exists': ('mxns/plib.html#pathlibmixin.exists', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.expanduser': ('mxns/plib.html#pathlibmixin.expanduser', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.glob': ('mxns/plib.html#pathlibmixin.glob', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.group': ('mxns/plib.html#pathlibmixin.group', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.hardlink_to': ('mxns/plib.html#pathlibmixin.hardlink_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.home': ('mxns/plib.html#pathlibmixin.home', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_absolute': ('mxns/plib.html#pathlibmixin.is_absolute', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_block_device': ( 'mxns/plib.html#pathlibmixin.is_block_device',
                                                                                 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_char_device': ( 'mxns/plib.html#pathlibmixin.is_char_device',
                                                                                'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_dir': ('mxns/plib.html#pathlibmixin.is_dir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_fifo': ('mxns/plib.html#pathlibmixin.is_fifo', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_file': ('mxns/plib.html#pathlibmixin.is_file', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_junction': ('mxns/plib.html#pathlibmixin.is_junction', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_mount': ('mxns/plib.html#pathlibmixin.is_mount', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_relative_to': ( 'mxns/plib.html#pathlibmixin.is_relative_to',
                                                                                'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_reserved': ('mxns/plib.html#pathlibmixin.is_reserved', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_socket': ('mxns/plib.html#pathlibmixin.is_socket', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.is_symlink': ('mxns/plib.html#pathlibmixin.is_symlink', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.iterdir': ('mxns/plib.html#pathlibmixin.iterdir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.joinpath': ('mxns/plib.html#pathlibmixin.joinpath', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.lchmod': ('mxns/plib.html#pathlibmixin.lchmod', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.link_to': ('mxns/plib.html#pathlibmixin.link_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.ls': ('mxns/plib.html#pathlibmixin.ls', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.lstat': ('mxns/plib.html#pathlibmixin.lstat', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.match': ('mxns/plib.html#pathlibmixin.match', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.mk_write': ('mxns/plib.html#pathlibmixin.mk_write', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.mkdir': ('mxns/plib.html#pathlibmixin.mkdir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.name': ('mxns/plib.html#pathlibmixin.name', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.open': ('mxns/plib.html#pathlibmixin.open', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.owner': ('mxns/plib.html#pathlibmixin.owner', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.parent': ('mxns/plib.html#pathlibmixin.parent', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.parents': ('mxns/plib.html#pathlibmixin.parents', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.parts': ('mxns/plib.html#pathlibmixin.parts', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.path': ('mxns/plib.html#pathlibmixin.path', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.read_bytes': ('mxns/plib.html#pathlibmixin.read_bytes', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.read_json': ('mxns/plib.html#pathlibmixin.read_json', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.read_text': ('mxns/plib.html#pathlibmixin.read_text', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.readlines': ('mxns/plib.html#pathlibmixin.readlines', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.readlink': ('mxns/plib.html#pathlibmixin.readlink', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.relative_to': ('mxns/plib.html#pathlibmixin.relative_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.relpath': ('mxns/plib.html#pathlibmixin.relpath', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.rename': ('mxns/plib.html#pathlibmixin.rename', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.replace': ('mxns/plib.html#pathlibmixin.replace', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.resolve': ('mxns/plib.html#pathlibmixin.resolve', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.rglob': ('mxns/plib.html#pathlibmixin.rglob', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.rmdir': ('mxns/plib.html#pathlibmixin.rmdir', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.root': ('mxns/plib.html#pathlibmixin.root', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.samefile': ('mxns/plib.html#pathlibmixin.samefile', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.stat': ('mxns/plib.html#pathlibmixin.stat', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.stem': ('mxns/plib.html#pathlibmixin.stem', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.suffix': ('mxns/plib.html#pathlibmixin.suffix', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.suffixes': ('mxns/plib.html#pathlibmixin.suffixes', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.symlink_to': ('mxns/plib.html#pathlibmixin.symlink_to', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.touch': ('mxns/plib.html#pathlibmixin.touch', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.unlink': ('mxns/plib.html#pathlibmixin.unlink', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.walk': ('mxns/plib.html#pathlibmixin.walk', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_name': ('mxns/plib.html#pathlibmixin.with_name', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_segments': ( 'mxns/plib.html#pathlibmixin.with_segments',
                                                                               'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_stem': ('mxns/plib.html#pathlibmixin.with_stem', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.with_suffix': ('mxns/plib.html#pathlibmixin.with_suffix', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.write_bytes': ('mxns/plib.html#pathlibmixin.write_bytes', 'xath/mxns/plib.py'),
                                'xath.mxns.plib.PathLibMixin.write_text': ('mxns/plib.html#pathlibmixin.write_text', 'xath/mxns/plib.py')},
            'xath.mxns.reqr': { 'xath.mxns.reqr.RequiredMixin': ('mxns/reqr.html#requiredmixin', 'xath/mxns/reqr.py'),
                                'xath.mxns.reqr.RequiredMixin.isvalid': ('mxns/reqr.html#requiredmixin.isvalid', 'xath/mxns/reqr.py'),
                                'xath.mxns.reqr.RequiredMixin.optional': ('mxns/reqr.html#requiredmixin.optional', 'xath/mxns/reqr.py')},
            'xath.name': { 'xath.name.NamedDir': ('name.html#nameddir', 'xath/name.py'),
                           'xath.name.NamedFile': ('name.html#namedfile', 'xath/name.py'),
                           'xath.name.NamedPath': ('name.html#namedpath', 'xath/name.py'),
                           'xath.name.NamedXath': ('name.html#namedxath', 'xath/name.py'),
                           'xath.name.NamedXath.__init__': ('name.html#namedxath.__init__', 'xath/name.py')},
            'xath.plib.lib': { 'xath.plib.lib.Path': ('plib/lib.html#path', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__enter__': ('plib/lib.html#path.__enter__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__exit__': ('plib/lib.html#path.__exit__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__init__': ('plib/lib.html#path.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.__new__': ('plib/lib.html#path.__new__', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path._make_child_relpath': ('plib/lib.html#path._make_child_relpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path._scandir': ('plib/lib.html#path._scandir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.absolute': ('plib/lib.html#path.absolute', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.chmod': ('plib/lib.html#path.chmod', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.cwd': ('plib/lib.html#path.cwd', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.exists': ('plib/lib.html#path.exists', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.expanduser': ('plib/lib.html#path.expanduser', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.glob': ('plib/lib.html#path.glob', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.group': ('plib/lib.html#path.group', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.hardlink_to': ('plib/lib.html#path.hardlink_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.home': ('plib/lib.html#path.home', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_block_device': ('plib/lib.html#path.is_block_device', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_char_device': ('plib/lib.html#path.is_char_device', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_dir': ('plib/lib.html#path.is_dir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_fifo': ('plib/lib.html#path.is_fifo', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_file': ('plib/lib.html#path.is_file', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_junction': ('plib/lib.html#path.is_junction', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_mount': ('plib/lib.html#path.is_mount', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_socket': ('plib/lib.html#path.is_socket', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.is_symlink': ('plib/lib.html#path.is_symlink', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.iterdir': ('plib/lib.html#path.iterdir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.lchmod': ('plib/lib.html#path.lchmod', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.lstat': ('plib/lib.html#path.lstat', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.mkdir': ('plib/lib.html#path.mkdir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.open': ('plib/lib.html#path.open', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.owner': ('plib/lib.html#path.owner', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.read_bytes': ('plib/lib.html#path.read_bytes', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.read_text': ('plib/lib.html#path.read_text', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.readlink': ('plib/lib.html#path.readlink', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.rename': ('plib/lib.html#path.rename', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.replace': ('plib/lib.html#path.replace', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.resolve': ('plib/lib.html#path.resolve', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.rglob': ('plib/lib.html#path.rglob', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.rmdir': ('plib/lib.html#path.rmdir', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.samefile': ('plib/lib.html#path.samefile', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.stat': ('plib/lib.html#path.stat', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.symlink_to': ('plib/lib.html#path.symlink_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.touch': ('plib/lib.html#path.touch', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.unlink': ('plib/lib.html#path.unlink', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.walk': ('plib/lib.html#path.walk', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.write_bytes': ('plib/lib.html#path.write_bytes', 'xath/plib/lib.py'),
                               'xath.plib.lib.Path.write_text': ('plib/lib.html#path.write_text', 'xath/plib/lib.py'),
                               'xath.plib.lib.PosixPath': ('plib/lib.html#posixpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath': ('plib/lib.html#purepath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__bytes__': ('plib/lib.html#purepath.__bytes__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__eq__': ('plib/lib.html#purepath.__eq__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__fspath__': ('plib/lib.html#purepath.__fspath__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__ge__': ('plib/lib.html#purepath.__ge__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__gt__': ('plib/lib.html#purepath.__gt__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__hash__': ('plib/lib.html#purepath.__hash__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__init__': ('plib/lib.html#purepath.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__le__': ('plib/lib.html#purepath.__le__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__lt__': ('plib/lib.html#purepath.__lt__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__new__': ('plib/lib.html#purepath.__new__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__reduce__': ('plib/lib.html#purepath.__reduce__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__repr__': ('plib/lib.html#purepath.__repr__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__rtruediv__': ('plib/lib.html#purepath.__rtruediv__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__str__': ('plib/lib.html#purepath.__str__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.__truediv__': ('plib/lib.html#purepath.__truediv__', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._format_parsed_parts': ( 'plib/lib.html#purepath._format_parsed_parts',
                                                                                'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._from_parsed_parts': ( 'plib/lib.html#purepath._from_parsed_parts',
                                                                              'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._lines': ('plib/lib.html#purepath._lines', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._load_parts': ('plib/lib.html#purepath._load_parts', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._parse_path': ('plib/lib.html#purepath._parse_path', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._parts_normcase': ('plib/lib.html#purepath._parts_normcase', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._str_normcase': ('plib/lib.html#purepath._str_normcase', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath._tail': ('plib/lib.html#purepath._tail', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.anchor': ('plib/lib.html#purepath.anchor', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.as_posix': ('plib/lib.html#purepath.as_posix', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.as_uri': ('plib/lib.html#purepath.as_uri', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.drive': ('plib/lib.html#purepath.drive', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.is_absolute': ('plib/lib.html#purepath.is_absolute', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.is_relative_to': ('plib/lib.html#purepath.is_relative_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.is_reserved': ('plib/lib.html#purepath.is_reserved', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.joinpath': ('plib/lib.html#purepath.joinpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.match': ('plib/lib.html#purepath.match', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.name': ('plib/lib.html#purepath.name', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.parent': ('plib/lib.html#purepath.parent', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.parents': ('plib/lib.html#purepath.parents', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.parts': ('plib/lib.html#purepath.parts', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.relative_to': ('plib/lib.html#purepath.relative_to', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.root': ('plib/lib.html#purepath.root', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.stem': ('plib/lib.html#purepath.stem', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.suffix': ('plib/lib.html#purepath.suffix', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.suffixes': ('plib/lib.html#purepath.suffixes', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_name': ('plib/lib.html#purepath.with_name', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_segments': ('plib/lib.html#purepath.with_segments', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_stem': ('plib/lib.html#purepath.with_stem', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePath.with_suffix': ('plib/lib.html#purepath.with_suffix', 'xath/plib/lib.py'),
                               'xath.plib.lib.PurePosixPath': ('plib/lib.html#pureposixpath', 'xath/plib/lib.py'),
                               'xath.plib.lib.PureWindowsPath': ('plib/lib.html#purewindowspath', 'xath/plib/lib.py'),
                               'xath.plib.lib.WindowsPath': ('plib/lib.html#windowspath', 'xath/plib/lib.py'),
                               'xath.plib.lib._DoubleRecursiveWildcardSelector': ( 'plib/lib.html#_doublerecursivewildcardselector',
                                                                                   'xath/plib/lib.py'),
                               'xath.plib.lib._DoubleRecursiveWildcardSelector._select_from': ( 'plib/lib.html#_doublerecursivewildcardselector._select_from',
                                                                                                'xath/plib/lib.py'),
                               'xath.plib.lib._ParentSelector': ('plib/lib.html#_parentselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._ParentSelector.__init__': ('plib/lib.html#_parentselector.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._ParentSelector._select_from': ( 'plib/lib.html#_parentselector._select_from',
                                                                               'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents': ('plib/lib.html#_pathparents', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__getitem__': ('plib/lib.html#_pathparents.__getitem__', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__init__': ('plib/lib.html#_pathparents.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__len__': ('plib/lib.html#_pathparents.__len__', 'xath/plib/lib.py'),
                               'xath.plib.lib._PathParents.__repr__': ('plib/lib.html#_pathparents.__repr__', 'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector': ('plib/lib.html#_recursivewildcardselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector.__init__': ( 'plib/lib.html#_recursivewildcardselector.__init__',
                                                                                      'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector._iterate_directories': ( 'plib/lib.html#_recursivewildcardselector._iterate_directories',
                                                                                                  'xath/plib/lib.py'),
                               'xath.plib.lib._RecursiveWildcardSelector._select_from': ( 'plib/lib.html#_recursivewildcardselector._select_from',
                                                                                          'xath/plib/lib.py'),
                               'xath.plib.lib._Selector': ('plib/lib.html#_selector', 'xath/plib/lib.py'),
                               'xath.plib.lib._Selector.__init__': ('plib/lib.html#_selector.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._Selector.select_from': ('plib/lib.html#_selector.select_from', 'xath/plib/lib.py'),
                               'xath.plib.lib._TerminatingSelector': ('plib/lib.html#_terminatingselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._TerminatingSelector._select_from': ( 'plib/lib.html#_terminatingselector._select_from',
                                                                                    'xath/plib/lib.py'),
                               'xath.plib.lib._WildcardSelector': ('plib/lib.html#_wildcardselector', 'xath/plib/lib.py'),
                               'xath.plib.lib._WildcardSelector.__init__': ('plib/lib.html#_wildcardselector.__init__', 'xath/plib/lib.py'),
                               'xath.plib.lib._WildcardSelector._select_from': ( 'plib/lib.html#_wildcardselector._select_from',
                                                                                 'xath/plib/lib.py'),
                               'xath.plib.lib._compile_pattern': ('plib/lib.html#_compile_pattern', 'xath/plib/lib.py'),
                               'xath.plib.lib._compile_pattern_lines': ('plib/lib.html#_compile_pattern_lines', 'xath/plib/lib.py'),
                               'xath.plib.lib._ignore_error': ('plib/lib.html#_ignore_error', 'xath/plib/lib.py'),
                               'xath.plib.lib._is_case_sensitive': ('plib/lib.html#_is_case_sensitive', 'xath/plib/lib.py'),
                               'xath.plib.lib._make_selector': ('plib/lib.html#_make_selector', 'xath/plib/lib.py'),
                               'xath.plib.lib.calc_raw_paths': ('plib/lib.html#calc_raw_paths', 'xath/plib/lib.py'),
                               'xath.plib.lib.psx_splitroot': ('plib/lib.html#psx_splitroot', 'xath/plib/lib.py'),
                               'xath.plib.lib.wdx_splitroot': ('plib/lib.html#wdx_splitroot', 'xath/plib/lib.py')},
            'xath.plib.psx': { 'xath.plib.psx._get_sep': ('plib/psx.html#_get_sep', 'xath/plib/psx.py'),
                               'xath.plib.psx._joinrealpath': ('plib/psx.html#_joinrealpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.abspath': ('plib/psx.html#abspath', 'xath/plib/psx.py'),
                               'xath.plib.psx.basename': ('plib/psx.html#basename', 'xath/plib/psx.py'),
                               'xath.plib.psx.commonpath': ('plib/psx.html#commonpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.dirname': ('plib/psx.html#dirname', 'xath/plib/psx.py'),
                               'xath.plib.psx.expanduser': ('plib/psx.html#expanduser', 'xath/plib/psx.py'),
                               'xath.plib.psx.expandvars': ('plib/psx.html#expandvars', 'xath/plib/psx.py'),
                               'xath.plib.psx.isabs': ('plib/psx.html#isabs', 'xath/plib/psx.py'),
                               'xath.plib.psx.isjunction': ('plib/psx.html#isjunction', 'xath/plib/psx.py'),
                               'xath.plib.psx.ismount': ('plib/psx.html#ismount', 'xath/plib/psx.py'),
                               'xath.plib.psx.join': ('plib/psx.html#join', 'xath/plib/psx.py'),
                               'xath.plib.psx.lexists': ('plib/psx.html#lexists', 'xath/plib/psx.py'),
                               'xath.plib.psx.normcase': ('plib/psx.html#normcase', 'xath/plib/psx.py'),
                               'xath.plib.psx.realpath': ('plib/psx.html#realpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.relpath': ('plib/psx.html#relpath', 'xath/plib/psx.py'),
                               'xath.plib.psx.split': ('plib/psx.html#split', 'xath/plib/psx.py'),
                               'xath.plib.psx.splitdrive': ('plib/psx.html#splitdrive', 'xath/plib/psx.py'),
                               'xath.plib.psx.splitext': ('plib/psx.html#splitext', 'xath/plib/psx.py'),
                               'xath.plib.psx.splitroot': ('plib/psx.html#splitroot', 'xath/plib/psx.py')},
            'xath.plib.wdx': { 'xath.plib.wdx._abspath_fallback': ('plib/wdx.html#_abspath_fallback', 'xath/plib/wdx.py'),
                               'xath.plib.wdx._get_bothseps': ('plib/wdx.html#_get_bothseps', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.basename': ('plib/wdx.html#basename', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.commonpath': ('plib/wdx.html#commonpath', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.dirname': ('plib/wdx.html#dirname', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.expanduser': ('plib/wdx.html#expanduser', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.expandvars': ('plib/wdx.html#expandvars', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.isabs': ('plib/wdx.html#isabs', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.ismount': ('plib/wdx.html#ismount', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.join': ('plib/wdx.html#join', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.lexists': ('plib/wdx.html#lexists', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.relpath': ('plib/wdx.html#relpath', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.split': ('plib/wdx.html#split', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.splitdrive': ('plib/wdx.html#splitdrive', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.splitext': ('plib/wdx.html#splitext', 'xath/plib/wdx.py'),
                               'xath.plib.wdx.splitroot': ('plib/wdx.html#splitroot', 'xath/plib/wdx.py')}}}
